@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2010-2022 Belledonne Communications SARL.
  *
- * This file is part of oRTP 
+ * This file is part of oRTP
  * (see https://gitlab.linphone.org/BC/public/ortp).
  *
  * This program is free software: you can redistribute it and/or modify
@@ -25,6 +25,7 @@
 #include "ortp/logging.h"
 #include "ortp/rtpsession.h"
 #include "rtpbundle.h"
+#include "rtpsession_priv.h"
 
 // C - Interface
 
@@ -43,11 +44,13 @@ extern "C" int rtp_bundle_get_mid_extension_id(RtpBundle *bundle) {
 extern "C" void rtp_bundle_set_mid_extension_id(RtpBundle *bundle, int id) {
 	((RtpBundleCxx *)bundle)->setMidId(id);
 }
-
 extern "C" void rtp_bundle_add_session(RtpBundle *bundle, const char *mid, RtpSession *session) {
 	((RtpBundleCxx *)bundle)->addSession(mid, session);
 }
-
+extern "C" void
+rtp_bundle_add_fec_session(RtpBundle *bundle, const RtpSession *source_session, RtpSession *fec_session) {
+	((RtpBundleCxx *)bundle)->addFecSession(source_session, fec_session);
+}
 extern "C" void rtp_bundle_remove_session_by_id(RtpBundle *bundle, const char *mid) {
 	((RtpBundleCxx *)bundle)->removeSession(mid);
 }
@@ -82,12 +85,15 @@ extern "C" bool_t rtp_bundle_dispatch(RtpBundle *bundle, bool_t is_rtp, mblk_t *
 	return ((RtpBundleCxx *)bundle)->dispatch(is_rtp, m);
 }
 
+extern "C" RtpSession *rtp_bundle_lookup_session_for_outgoing_packet(RtpBundle *bundle, mblk_t *m) {
+	return ((RtpBundleCxx *)bundle)->checkForSession(m, true);
+}
+
 // C++ - Implementation
 
 RtpBundleCxx::~RtpBundleCxx() {
 	clear();
 }
-
 int RtpBundleCxx::getMidId() const {
 	return midId;
 }
@@ -95,11 +101,10 @@ int RtpBundleCxx::getMidId() const {
 void RtpBundleCxx::setMidId(int id) {
 	midId = id;
 }
-
 void RtpBundleCxx::addSession(const std::string &mid, RtpSession *session) {
 	auto it =
-		std::find_if(sessions.begin(), sessions.end(),
-					 [session](const std::pair<std::string, RtpSession *> &t) -> bool { return t.second == session; });
+	    std::find_if(sessions.begin(), sessions.end(),
+	                 [session](const std::pair<std::string, RtpSession *> &t) -> bool { return t.second == session; });
 
 	if (it != sessions.end()) {
 		ortp_error("RtpBundle [%p]: Cannot add session (%p) has it is already in the bundle", this, session);
@@ -108,17 +113,32 @@ void RtpBundleCxx::addSession(const std::string &mid, RtpSession *session) {
 
 	sessions.emplace(mid, session);
 
-	session->bundle = (RtpBundle *)this;
-
 	if (!primary) {
 		primary = session;
 		session->is_primary = TRUE;
 	}
+	rtp_session_set_bundle(session, (RtpBundle *)this);
+}
+void RtpBundleCxx::addFecSession(const RtpSession *sourceSession, RtpSession *fecSession) {
+	auto it = std::find_if(
+	    sessions.begin(), sessions.end(),
+	    [sourceSession](const std::pair<std::string, RtpSession *> &t) -> bool { return t.second == sourceSession; });
+
+	if (it == sessions.end()) {
+		ortp_error("RtpBundle [%p]: Cannot add session (%p) because the associated source session isn't in the bundle",
+		           this, fecSession);
+		return;
+	}
+	std::string mid = getSessionMid(it->second);
+	fec_sessions.emplace(mid, fecSession);
+	rtp_session_set_bundle(fecSession, (RtpBundle *)this);
+	ortp_message("Fec session [%u] added to the bundle", rtp_session_get_send_ssrc(fecSession));
 }
 
 void RtpBundleCxx::removeSession(const std::string &mid) {
 	auto session = sessions.find(mid);
 	if (session != sessions.end()) {
+		rtp_session_set_bundle(session->second, NULL);
 		if (session->second == primary) {
 			primary->is_primary = FALSE;
 			primary = NULL;
@@ -134,15 +154,22 @@ void RtpBundleCxx::removeSession(const std::string &mid) {
 		}
 		ssrcToMidMutex.unlock();
 
-		session->second->bundle = NULL;
+		if (session->second->fec_stream != NULL) {
+			auto fec_session = fec_sessions.find(mid);
+			if (fec_session != fec_sessions.end()) {
+				rtp_session_set_bundle(fec_session->second, NULL);
+				fec_sessions.erase(mid);
+			}
+		}
+
 		sessions.erase(mid);
 	}
 }
 
 void RtpBundleCxx::removeSession(RtpSession *session) {
 	auto it =
-		std::find_if(sessions.begin(), sessions.end(),
-					 [session](const std::pair<std::string, RtpSession *> &t) -> bool { return t.second == session; });
+	    std::find_if(sessions.begin(), sessions.end(),
+	                 [session](const std::pair<std::string, RtpSession *> &t) -> bool { return t.second == session; });
 
 	if (it != sessions.end()) {
 		removeSession(it->first);
@@ -152,13 +179,16 @@ void RtpBundleCxx::removeSession(RtpSession *session) {
 void RtpBundleCxx::clear() {
 	for (const auto &entry : sessions) {
 		RtpSession *session = entry.second;
-
 		session->bundle = NULL;
 	}
-
+	for (const auto &entry : fec_sessions) {
+		RtpSession *session = entry.second;
+		session->bundle = NULL;
+	}
 	primary = NULL;
 	ssrcToMid.clear();
 	sessions.clear();
+	fec_sessions.clear();
 }
 
 RtpSession *RtpBundleCxx::getPrimarySession() const {
@@ -179,11 +209,18 @@ void RtpBundleCxx::setPrimarySession(const std::string &mid) {
 
 const std::string &RtpBundleCxx::getSessionMid(RtpSession *session) const {
 	auto it =
-		std::find_if(sessions.begin(), sessions.end(),
-					 [session](const std::pair<std::string, RtpSession *> &t) -> bool { return t.second == session; });
+	    std::find_if(sessions.begin(), sessions.end(),
+	                 [session](const std::pair<std::string, RtpSession *> &t) -> bool { return t.second == session; });
 
 	if (it != sessions.end()) {
 		return it->first;
+	} else { // Could be a FEC session
+		it = std::find_if(
+		    fec_sessions.begin(), fec_sessions.end(),
+		    [session](const std::pair<std::string, RtpSession *> &t) -> bool { return t.second == session; });
+		if (it != sessions.end()) {
+			return it->first;
+		}
 	}
 
 	throw std::string("the session must be in the bundle!");
@@ -218,8 +255,11 @@ bool RtpBundleCxx::updateMid(const std::string &mid, const uint32_t ssrc, const
 	return false;
 }
 
-static void getSsrcFromSdes(void *userData, uint32_t ssrc, rtcp_sdes_type_t t, BCTBX_UNUSED(const char *content),
-							BCTBX_UNUSED(uint8_t contentLen)) {
+static void getSsrcFromSdes(void *userData,
+                            uint32_t ssrc,
+                            rtcp_sdes_type_t t,
+                            BCTBX_UNUSED(const char *content),
+                            BCTBX_UNUSED(uint8_t contentLen)) {
 	uint32_t *value = (uint32_t *)userData;
 
 	if (*value == 0 || t == RTCP_SDES_MID) {
@@ -227,7 +267,7 @@ static void getSsrcFromSdes(void *userData, uint32_t ssrc, rtcp_sdes_type_t t, B
 	}
 }
 
-static uint32_t getSsrcFromMessage(mblk_t *m, bool isRtp) {
+static uint32_t getSsrcFromMessage(const mblk_t *m, bool isRtp) {
 	if (isRtp) {
 		return rtp_get_ssrc(m);
 	}
@@ -236,37 +276,37 @@ static uint32_t getSsrcFromMessage(mblk_t *m, bool isRtp) {
 	uint32_t ssrc = 0;
 
 	switch (rtcp_common_header_get_packet_type(ch)) {
-	case RTCP_SR:
-		return rtcp_SR_get_ssrc(m);
-	case RTCP_RR:
-		return rtcp_RR_get_ssrc(m);
-	case RTCP_SDES:
-		rtcp_sdes_parse(m, getSsrcFromSdes, &ssrc);
-		return ssrc;
-	case RTCP_BYE:
-		if (rtcp_BYE_get_ssrc(m, 0, &ssrc)) {
+		case RTCP_SR:
+			return rtcp_SR_get_ssrc(m);
+		case RTCP_RR:
+			return rtcp_RR_get_ssrc(m);
+		case RTCP_SDES:
+			rtcp_sdes_parse(m, getSsrcFromSdes, &ssrc);
 			return ssrc;
-		}
-		return -1;
-	case RTCP_APP:
-		return rtcp_APP_get_ssrc(m);
-	case RTCP_RTPFB:
-		return rtcp_RTPFB_get_packet_sender_ssrc(m);
-	case RTCP_PSFB:
-		return rtcp_PSFB_get_packet_sender_ssrc(m);
-	case RTCP_XR:
-		return rtcp_XR_get_ssrc(m);
-	default:
-		ortp_warning("Unknown RTCP packet type (%u) while retrieving it's SSRC",
-					 rtcp_common_header_get_packet_type(ch));
-		break;
+		case RTCP_BYE:
+			if (rtcp_BYE_get_ssrc(m, 0, &ssrc)) {
+				return ssrc;
+			}
+			return -1;
+		case RTCP_APP:
+			return rtcp_APP_get_ssrc(m);
+		case RTCP_RTPFB:
+			return rtcp_RTPFB_get_packet_sender_ssrc(m);
+		case RTCP_PSFB:
+			return rtcp_PSFB_get_packet_sender_ssrc(m);
+		case RTCP_XR:
+			return rtcp_XR_get_ssrc(m);
+		default:
+			ortp_warning("Unknown RTCP packet type (%u) while retrieving it's SSRC",
+			             rtcp_common_header_get_packet_type(ch));
+			break;
 	}
 
 	return -1;
 }
 
-static void checkForSessionSdesCallback(void *userData, uint32_t ssrc, rtcp_sdes_type_t t, const char *content,
-										uint8_t contentLen) {
+void RtpBundleCxx::checkForSessionSdesCallback(
+    void *userData, uint32_t ssrc, rtcp_sdes_type_t t, const char *content, uint8_t contentLen) {
 	RtpBundleCxx *bundle = (RtpBundleCxx *)userData;
 	std::string value(content, contentLen);
 
@@ -274,25 +314,24 @@ static void checkForSessionSdesCallback(void *userData, uint32_t ssrc, rtcp_sdes
 		// Update the mid map with the corresponding session
 		if (!bundle->updateMid(value, ssrc, UINT16_MAX, false)) {
 			ortp_warning("Rtp Bundle [%p]: SSRC %u not found and SDES mid \"%s\" from msg does not "
-						 "correspond to any sessions",
-						 bundle, ssrc, value.c_str());
+			             "correspond to any sessions",
+			             bundle, ssrc, value.c_str());
 		}
 
 		bundle->sdesParseMid = value;
 	}
 }
 
-RtpSession *RtpBundleCxx::checkForSession(mblk_t *m, bool isRtp) {
+RtpSession *RtpBundleCxx::checkForSession(const mblk_t *m, bool isRtp) {
 	const std::lock_guard<std::mutex> guard(ssrcToMidMutex);
+	uint32_t ssrc;
 
-	rtp_header_t *rtp = (rtp_header_t *)m->b_rptr;
-	if (isRtp && rtp->version != 2) {
+	if (isRtp && rtp_get_version(m) != 2) {
 		/* STUN packet*/
 		return primary;
 	}
 
-	uint32_t ssrc = getSsrcFromMessage(m, isRtp);
-
+	ssrc = getSsrcFromMessage(m, isRtp);
 	auto it = ssrcToMid.find(ssrc);
 
 	if (isRtp) {
@@ -308,22 +347,22 @@ RtpSession *RtpBundleCxx::checkForSession(mblk_t *m, bool isRtp) {
 				if (!updateMid(mid, ssrc, rtp_get_seqnumber(m), true)) {
 					if (it == ssrcToMid.end()) {
 						ortp_warning("Rtp Bundle [%p]: SSRC %u not found and mid \"%s\" from msg (%d) does not "
-									 "correspond to any sessions",
-									 this, ssrc, mid.c_str(), (int)rtp_get_seqnumber(m));
+						             "correspond to any sessions",
+						             this, ssrc, mid.c_str(), (int)rtp_get_seqnumber(m));
 						return NULL;
 					}
 				}
 			} else {
 				if (it == ssrcToMid.end()) {
 					ortp_warning("Rtp Bundle [%p]: SSRC %u not found and msg (%d) does not have a mid extension header",
-								 this, ssrc, (int)rtp_get_seqnumber(m));
+					             this, ssrc, (int)rtp_get_seqnumber(m));
 					return NULL;
 				}
 			}
 		} else {
 			if (it == ssrcToMid.end()) {
 				ortp_warning("Rtp Bundle [%p]: SSRC %u not found and msg (%d) does not have an extension header", this,
-							 ssrc, (int)rtp_get_seqnumber(m));
+				             ssrc, (int)rtp_get_seqnumber(m));
 				return NULL;
 			}
 		}
@@ -353,9 +392,16 @@ RtpSession *RtpBundleCxx::checkForSession(mblk_t *m, bool isRtp) {
 	} else {
 		try {
 			auto session = sessions.at(it->second.mid);
+			if (session->fec_stream) {
+				RtpSession *fec_session = fec_stream_get_fec_session(session->fec_stream);
+				if (rtp_session_get_recv_payload_type(fec_session) == rtp_get_payload_type(m)) {
+					return fec_session;
+				}
+			}
 			return session;
-		} catch (std::out_of_range&) {
-			ortp_warning("Rtp Bundle [%p]: Unable to find session with mid %s (SSRC %u)", this, it->second.mid.c_str(), ssrc);
+		} catch (std::out_of_range &) {
+			ortp_warning("Rtp Bundle [%p]: Unable to find session with mid %s (SSRC %u)", this, it->second.mid.c_str(),
+			             ssrc);
 			return nullptr;
 		}
 	}
@@ -381,7 +427,6 @@ bool RtpBundleCxx::dispatchRtpMessage(mblk_t *m) {
 		ortp_mutex_lock(&session->rtp.gs.bundleq_lock);
 		putq(&session->rtp.gs.bundleq, m);
 		ortp_mutex_unlock(&session->rtp.gs.bundleq_lock);
-
 		return true;
 	}
 
@@ -390,20 +435,24 @@ bool RtpBundleCxx::dispatchRtpMessage(mblk_t *m) {
 
 bool RtpBundleCxx::dispatchRtcpMessage(mblk_t *m) {
 	mblk_t *primarymsg = NULL;
+	const mblk_t *m_rtcp;
 
 	// Check if the packet contains a SDES first
+	RtcpParserContext rtcp_parser_ctx;
+	m_rtcp = rtcp_parser_context_init(&rtcp_parser_ctx, m);
 	do {
-		if (rtcp_is_SDES(m)) {
+		if (rtcp_is_SDES(m_rtcp)) {
 			// call checkForSession that will update the mid table
-			checkForSession(m, false);
+			checkForSession(m_rtcp, false);
 		}
-	} while (rtcp_next_packet(m));
-	rtcp_rewind(m);
+	} while ((m_rtcp = rtcp_parser_context_next_packet(&rtcp_parser_ctx)) != NULL);
+
+	m_rtcp = rtcp_parser_context_start(&rtcp_parser_ctx);
 
 	do {
-		mblk_t *tmp = dupmsg(m);
-		tmp->b_rptr = m->b_rptr;
-		tmp->b_wptr = tmp->b_rptr + rtcp_get_size(m);
+
+		mblk_t *tmp = dupmsg((mblk_t *)m_rtcp); /* const qualifier discarded intentionally*/
+		tmp->b_wptr = tmp->b_rptr + rtcp_get_size(m_rtcp);
 
 		// TODO: some RTCP packet can be for multiple session (e.g. BYE)
 
@@ -421,25 +470,24 @@ bool RtpBundleCxx::dispatchRtcpMessage(mblk_t *m) {
 		} else {
 			const rtcp_common_header_t *ch = rtcp_get_common_header(tmp);
 			ortp_warning("Rtp Bundle [%p]: Rctp msg (%d) ssrc=%u does not correspond to any sessions", this,
-						 rtcp_common_header_get_packet_type(ch), getSsrcFromMessage(tmp, false));
+			             rtcp_common_header_get_packet_type(ch), getSsrcFromMessage(tmp, false));
 			freemsg(tmp);
 		}
-	} while (rtcp_next_packet(m));
-	rtcp_rewind(m);
+	} while ((m_rtcp = rtcp_parser_context_next_packet(&rtcp_parser_ctx)) != NULL);
+
+	rtcp_parser_context_uninit(&rtcp_parser_ctx);
 
 	if (primarymsg) {
 		msgpullup(primarymsg, (size_t)-1);
+		msgpullup(m, (size_t)-1);
 
-		// TODO: Fix when possible
+		// FIXME: not so elegant to copy back to the original mblk_t.
 		size_t len = primarymsg->b_wptr - primarymsg->b_rptr;
 		memcpy(m->b_rptr, primarymsg->b_rptr, len);
 		m->b_wptr = m->b_rptr + len;
-
 		freemsg(primarymsg);
-
 		return false;
 	}
-
 	freemsg(m);
 	return true;
 }
