@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2010-2022 Belledonne Communications SARL.
  *
- * This file is part of oRTP 
+ * This file is part of oRTP
  * (see https://gitlab.linphone.org/BC/public/ortp).
  *
  * This program is free software: you can redistribute it and/or modify
@@ -18,17 +18,14 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "ortp/ortp.h"
 #include "rtptimer.h"
+#include "ortp/ortp.h"
 
-void rtp_timer_set_interval(RtpTimer *timer, struct timeval *interval)
-{
-	if (timer->state==RTP_TIMER_RUNNING){
+void rtp_timer_set_interval(RtpTimer *timer, struct timeval *interval) {
+	if (timer->state == RTP_TIMER_RUNNING) {
 		ortp_warning("Cannot change timer interval while it is running.\n");
 		return;
 	}
-	timer->interval.tv_sec=interval->tv_sec;
-	timer->interval.tv_usec=interval->tv_usec;
+	timer->interval.tv_sec = interval->tv_sec;
+	timer->interval.tv_usec = interval->tv_usec;
 }
-
-
