@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2010-2022 Belledonne Communications SARL.
  *
- * This file is part of oRTP 
+ * This file is part of oRTP
  * (see https://gitlab.linphone.org/BC/public/ortp).
  *
  * This program is free software: you can redistribute it and/or modify
@@ -19,55 +19,49 @@
  */
 #include <windows.h>
 
-#include "winrttimer.h"
 #include "ortp/logging.h"
+#include "winrttimer.h"
 
 #ifndef ORTP_WINDOWS_DESKTOP
 
 #ifdef ORTP_WINDOWS_PHONE
-#using <Windows.winmd>
+#using < Windows.winmd>
 #endif
 
 using namespace Windows::Foundation;
 using namespace Windows::System::Threading;
 
-class WinRTTimer
-{
+class WinRTTimer {
 public:
 	WinRTTimer();
 	~WinRTTimer();
 	void run();
+
 private:
-	ThreadPoolTimer^ PeriodicTimer;
+	ThreadPoolTimer ^ PeriodicTimer;
 	HANDLE SleepEvent;
 	ULONGLONG LateTicks;
 	ULONGLONG PosixTimerTime;
 	ULONGLONG OffsetTime;
 };
 
-
-WinRTTimer::WinRTTimer()
-	: LateTicks(0), PosixTimerTime(0), OffsetTime(GetTickCount64())
-{
+WinRTTimer::WinRTTimer() : LateTicks(0), PosixTimerTime(0), OffsetTime(GetTickCount64()) {
 	TimeSpan period;
 	period.Duration = TIME_INTERVAL * 10000;
 	SleepEvent = CreateEventEx(NULL, NULL, CREATE_EVENT_MANUAL_RESET, EVENT_ALL_ACCESS);
-	PeriodicTimer = ThreadPoolTimer::CreatePeriodicTimer(
-		ref new TimerElapsedHandler([this](ThreadPoolTimer^ source)
-		{
-			if (source == PeriodicTimer) {
-				PosixTimerTime += TIME_INTERVAL;
-			}
-		}), period);
+	PeriodicTimer = ThreadPoolTimer::CreatePeriodicTimer(ref new TimerElapsedHandler([this](ThreadPoolTimer ^ source) {
+		                                                     if (source == PeriodicTimer) {
+			                                                     PosixTimerTime += TIME_INTERVAL;
+		                                                     }
+	                                                     }),
+	                                                     period);
 }
 
-WinRTTimer::~WinRTTimer()
-{
+WinRTTimer::~WinRTTimer() {
 	PeriodicTimer->Cancel();
 }
 
-void WinRTTimer::run()
-{
+void WinRTTimer::run() {
 	// If timer have expired while we where out of this method
 	// Try to run after lost time.
 	if (LateTicks > 0) {
@@ -88,18 +82,15 @@ void WinRTTimer::run()
 
 static WinRTTimer *timer;
 
-void winrt_timer_init(void)
-{
+void winrt_timer_init(void) {
 	timer = new WinRTTimer();
 }
 
-void winrt_timer_do(void)
-{
+void winrt_timer_do(void) {
 	timer->run();
 }
 
-void winrt_timer_close(void)
-{
+void winrt_timer_close(void) {
 	delete timer;
 }
 
